==> javie-0.3.0-src.tar.gz: javie-0.3.0-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/VideoLayerBufferImpl.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal;

import ch.kuramo.javie.core.BlendMode;
import ch.kuramo.javie.core.DepthBuffer;
import ch.kuramo.javie.core.VideoBuffer;
import ch.kuramo.javie.core.VideoLayerBuffer;

class VideoLayerBufferImpl implements VideoLayerBuffer {

	private VideoBuffer _videoBuffer;

	private DepthBuffer _depthBuffer;

	private final BlendMode _blendMode;


	VideoLayerBufferImpl(VideoBuffer videoBuffer, DepthBuffer depthBuffer, BlendMode blendMode) {
		_videoBuffer = videoBuffer;
		_depthBuffer = depthBuffer;
		_blendMode = blendMode;
	}

	public void dispose() {
		if (_videoBuffer != null) {
			_videoBuffer.dispose();
			_videoBuffer = null;
		}
		if (_depthBuffer != null) {
			_depthBuffer.dispose();
			_depthBuffer = null;
		}
	}

	public VideoBuffer getVideoBuffer() {
		return _videoBuffer;
	}

	public DepthBuffer getDepthBuffer() {
		return _depthBuffer;
	}

	public BlendMode getBlendMode() {
		return _blendMode;
	}

}

==> javie-0.3.10-src.tar.gz: javie-0.3.10-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/VideoLayerBufferImpl.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal;

import ch.kuramo.javie.core.BlendMode;
import ch.kuramo.javie.core.DepthBuffer;
import ch.kuramo.javie.core.VideoBuffer;
import ch.kuramo.javie.core.VideoLayerBuffer;

class VideoLayerBufferImpl implements VideoLayerBuffer {

	private VideoBuffer _videoBuffer;

	private DepthBuffer _depthBuffer;

	private final BlendMode _blendMode;

	private final double _opacity;


	VideoLayerBufferImpl(VideoBuffer videoBuffer, DepthBuffer depthBuffer, BlendMode blendMode, double opacity) {
		_videoBuffer = videoBuffer;
		_depthBuffer = depthBuffer;
		_blendMode = blendMode;
		_opacity = opacity;
	}

	public void dispose() {
		if (_videoBuffer != null) {
			_videoBuffer.dispose();
			_videoBuffer = null;
		}
		if (_depthBuffer != null) {
			_depthBuffer.dispose();
			_depthBuffer = null;
		}
	}

	public VideoBuffer getVideoBuffer() {
		return _videoBuffer;
	}

	public DepthBuffer getDepthBuffer() {
		return _depthBuffer;
	}

	public BlendMode getBlendMode() {
		return _blendMode;
	}

	public double getOpacity() {
		return _opacity;
	}

}
